accounts method
Returns all financial accounts the user has authorized access to.
Implementation
@override
Future<List<FinancialAccount>> accounts() async => _accounts;
Returns all financial accounts the user has authorized access to.
@override
Future<List<FinancialAccount>> accounts() async => _accounts;