balanceHistory method
Returns all stored balance snapshots for the given accountId.
Implementation
@override
Future<List<AccountBalance>> balanceHistory(String accountId) async =>
_balances.where((b) => b.accountId == accountId).toList();
Returns all stored balance snapshots for the given accountId.
@override
Future<List<AccountBalance>> balanceHistory(String accountId) async =>
_balances.where((b) => b.accountId == accountId).toList();