accountUpdates abstract method
A stream that emits the full updated account list whenever accounts are added, modified, or removed.
Implementation
Stream<List<FinancialAccount>> accountUpdates();
A stream that emits the full updated account list whenever accounts are added, modified, or removed.
Stream<List<FinancialAccount>> accountUpdates();