accounts abstract method
Returns all financial accounts the user has authorized access to.
Implementation
Future<List<FinancialAccount>> accounts();
Returns all financial accounts the user has authorized access to.
Future<List<FinancialAccount>> accounts();