balanceHistory abstract method
Returns all stored balance snapshots for the given accountId.
Implementation
Future<List<AccountBalance>> balanceHistory(String accountId);
Returns all stored balance snapshots for the given accountId.
Future<List<AccountBalance>> balanceHistory(String accountId);