transactionUpdates abstract method
A stream that emits an updated list of transactions whenever FinanceKit reports a change.
Implementation
Stream<List<Transaction>> transactionUpdates(TransactionQuery query);
A stream that emits an updated list of transactions whenever FinanceKit reports a change.
Stream<List<Transaction>> transactionUpdates(TransactionQuery query);