FinancialAccount class

A financial account linked in Apple Wallet.

Constructors

FinancialAccount({required String id, required String displayName, required AccountType accountType, required String institutionName, String? currencyCode})
Creates a FinancialAccount.
const
FinancialAccount.fromMap(Map<Object?, Object?> map)
Deserializes from a native method-channel map.
factory

Properties

accountType AccountType
Whether this is an asset or liability account.
final
currencyCode String?
The ISO 4217 currency code the account is denominated in, if known.
final
displayName String
The user-facing name of the account.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique account identifier (UUID string).
final
institutionName String
The name of the financial institution that holds the account.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited