TransactionQuery class
Parameters for filtering a transaction query.
Constructors
- TransactionQuery({String? accountId, DateTime? startDate, DateTime? endDate, int? limit})
-
Creates a TransactionQuery with optional filters.
const
Properties
- accountId → String?
-
Restrict results to a specific account (UUID string).
final
- endDate → DateTime?
-
Exclude transactions after this date.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum number of transactions to return.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
Exclude transactions before this date.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes to a method-channel–compatible map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited